@@ -1,5 +1,6 @@
 import random
 
+
 class UserAgent(object):
 
     def __init__(self):
@@ -267,5 +268,5 @@ class UserAgent(object):
         }
 
     def random(self):
-        browser = random.choice(self.browsers.keys())
-        return random.choice(self.browsers[browser])
\ No newline at end of file
+        browser = random.choice(list(self.browsers.keys()))
+        return random.choice(self.browsers[browser])
