@@ -1,6 +1,7 @@
 from importlib import import_module
+from servicelayer.extensions import get_entry_point
 
-from memorious.core import connect_redis
+from memorious.model import Crawl
 
 
 class CrawlerStage(object):
@@ -13,28 +14,27 @@ class CrawlerStage(object):
         self.method_name = config.get('method')
         self.params = config.get('params') or {}
         self.handlers = config.get('handle') or {}
-        self.rate_limit = None
-        if 'rate_limit' in config:
-            self.rate_limit = float(config.get('rate_limit'))
 
     @property
     def method(self):
-        method = self.method_name
-        package = 'memorious.operations'
-        if ':' in method:
-            package, method = method.rsplit(':', 1)
+        # method A: via a named Python entry point
+        func = get_entry_point('memorious.operations', self.method_name)
+        if func is not None:
+            return func
+        # method B: direct import from a module
+        if ':' not in self.method_name:
+            raise ValueError("Unknown method: %s", self.method_name)
+        package, method = self.method_name.rsplit(':', 1)
         module = import_module(package)
         return getattr(module, method)
 
     @property
     def op_count(self):
         """Total operations performed for this stage"""
-        conn = connect_redis()
-        if conn is None:
-            return None
-        total_ops = conn.get(self.crawler.name + ":" + self.name)
-        if total_ops:
-            return int(total_ops)
+        return Crawl.op_count(self.crawler, self)
+
+    def __str__(self):
+        return self.name
 
     def __repr__(self):
         return '<CrawlerStage(%r, %s)>' % (self.crawler, self.name)
