@@ -1,6 +1,6 @@
 import logging
 
-from servicelayer.jobs import Stage, Job, Dataset
+from servicelayer.jobs import Job
 
 from memorious.core import conn
 from memorious.settings import MAX_QUEUE_LENGTH
@@ -17,9 +17,9 @@ class Queue(object):
         crawler = state.get('crawler')
         job = Job(conn, str(crawler), state['run_id'])
         job_stage = job.get_stage(stage)
+        job_stage.sync()
         queue_length = job_stage.get_status().get('pending')
         if queue_length > MAX_QUEUE_LENGTH:
             msg = "queue for %s:%s too big."
             raise QueueTooBigError(msg % (str(crawler), stage))
         job_stage.queue(payload=data, context=state)
-
